package edu.nyu.scps.audio;

import java.io.IOException;

import android.app.Activity;
import android.media.MediaPlayer;
import android.media.MediaPlayer.OnCompletionListener;
import android.media.MediaPlayer.OnErrorListener;
import android.os.Bundle;
import android.view.View;
import android.widget.Toast;
import android.widget.ToggleButton;

public class AudioActivity extends Activity {
	MediaPlayer mediaPlayer;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		final ToggleButton toggleButton = (ToggleButton)findViewById(R.id.toggleButton);

		toggleButton.setOnClickListener(new View.OnClickListener() {

			public void onClick(View v) {
				if (((ToggleButton)v).isChecked()) {
					if (mediaPlayer == null) {

						//Here to create a new MediaPlayer.  Must be released in onDestroy.
						mediaPlayer = MediaPlayer.create(AudioActivity.this, R.raw.china);	//calls prepare
						if (mediaPlayer == null) {
							Toast.makeText(AudioActivity.this, "couldn't create MediaPayer", Toast.LENGTH_LONG).show();
						}

						mediaPlayer.setOnErrorListener(new OnErrorListener() {
							@Override
							public boolean onError(MediaPlayer mp, int what, int extra) {
								String s =
									what == MediaPlayer.MEDIA_ERROR_UNKNOWN ? "MEDIA_ERROR_UNKNOWN" :
									what == MediaPlayer.MEDIA_ERROR_SERVER_DIED ? "MEDIA_ERROR_SERVER_DIED" :
									Integer.toString(what);
						
								Toast.makeText(AudioActivity.this, s + " " + extra, Toast.LENGTH_LONG).show();
								return true;
							}
						});

						mediaPlayer.setOnCompletionListener(new OnCompletionListener() {
							@Override
							public void onCompletion(MediaPlayer mp) {
								mediaPlayer.stop();
								toggleButton.setChecked(false);
							}
						});

					} else {
						//Here to turn an existing MediaPlayer back on.
						try {
							mediaPlayer.prepare();
						}
						
						catch (IllegalStateException e) {
							Toast.makeText(AudioActivity.this, e.toString(), Toast.LENGTH_LONG).show();
						}
						
						catch (IOException e) {
							Toast.makeText(AudioActivity.this, e.toString(), Toast.LENGTH_LONG).show();
						}
					}

					mediaPlayer.start();
				} else {
					//Here when the ToggleButton is unchecked.
					if (mediaPlayer != null && mediaPlayer.isPlaying()) {
						mediaPlayer.stop();
					}
				}
			}
		});
	}
	
	@Override
    protected void onDestroy() {
        if (mediaPlayer != null) {
            mediaPlayer.release();
            mediaPlayer = null;
        }
        super.onDestroy();
    }
}